@@ -1,15 +1,12 @@
 package Quantum::Superpositions::Lazy::Util;
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
-use v5.28;
+use v5.24;
 use warnings;
-use feature qw(signatures);
-no warnings qw(experimental::signatures);
-
 use Exporter qw(import);
 use Scalar::Util qw(blessed);
-use Data::Entropy::Algorithms qw(rand_flt);
+use Random::Any qw(rand);
 
 our @EXPORT_OK = qw(
 	is_collapsible
@@ -17,16 +14,20 @@ our @EXPORT_OK = qw(
 	get_rand
 );
 
-sub is_collapsible ($item)
+sub is_collapsible
 {
+	my ($item) = @_;
+
 	return blessed $item && $item->DOES("Quantum::Superpositions::Lazy::Role::Collapsible");
 }
 
-sub is_state ($item)
+sub is_state
 {
+	my ($item) = @_;
+
 	return blessed $item && $item->isa("Quantum::Superpositions::Lazy::State");
 }
 
-sub get_rand { rand_flt 0, 1 }
+sub get_rand { rand() }
 
 1;
